@@ -1,10 +1,10 @@
 makessp <-
   function(formula,data,type=NULL,nknots=NULL,rparm=NA,
            lambdas=NULL,skip.iter=TRUE,se.fit=FALSE,rseed=1234,
-           gcvopts=NULL,knotcheck=TRUE,thetas=NULL){
+           gcvopts=NULL,knotcheck=TRUE,thetas=NULL,weights=NULL){
     ###### Makes Smoothing Splines with Parametric effects
-    ###### Nathaniel E. Helwig (nhelwig2@illinois.edu)
-    ###### Last modified: July 11, 2014
+    ###### Nathaniel E. Helwig (helwig@umn.edu)
+    ###### Last modified: August 26, 2014
     
     ### get initial info 
     mf=match.call()
@@ -29,6 +29,27 @@ makessp <-
     if(nrow(yvar)!=ndpts){stop("Response vector must have same length as predictors.")}
     ysm=sum(yvar);  nunewr=ndpts;  fweights=rep.int(1L,ndpts);  yty=crossprod(yvar)
     
+    ### check gcvopts
+    if(is.null(gcvopts[1])==FALSE){
+      gmatch=match(c("maxit","gcvtol","alpha"),names(gcvopts))
+      if(any(is.na(gmatch))){stop("Invalid input for 'gcvopts'.")}
+      gcvopts$maxit=as.integer(gcvopts$maxit[1])
+      gcvopts$gcvtol=gcvopts$gcvtol[1]
+      gcvopts$alpha=gcvopts$alpha[1]
+      ugcv=unlist(gcvopts)
+      if(any(ugcv<=0)){stop("Invalid input for 'gcvopts'.")}
+      if(gcvopts$maxit<1L){stop("Invalid input for gcvopts$maxit")}
+    }
+    
+    ### check weights
+    if(is.null(weights[1])==FALSE){
+      weights=as.numeric(weights)
+      if(length(weights)!=ndpts){stop("Weights vector must have same length as response.")}
+      if(any(weights<=0)){stop("Weights must be positive.")}
+      if(is.na(rparm[1])==FALSE & min(weights)<=0.005){stop("Minimum weight is too small (less than 0.005).")}
+      wtchk=TRUE
+    } else {weights=1; wtchk=FALSE}
+    
     ### check order of things for nonparametric predictors
     if(nxvar>1){
       snidx=match(xnames,names(type))
@@ -154,6 +175,12 @@ makessp <-
           xvars[[k]]=as.matrix(gidx*rparm[[k]]);  rm(gidx)
         }
       } # end for(k in 1:nxvar)
+      # account for weights
+      if(wtchk){
+        rmw=round(min(weights)/.01)*.01
+        gvec = gvec + kconst*round((weights-rmw)/.01)
+        weights=round(weights/.01)*.01
+      }
       # get unique points, frequencies, and sums
       gvec=as.factor(gvec)
       glindx=split(cbind(1:ndpts,yvar),gvec)
@@ -161,6 +188,7 @@ makessp <-
       fs=matrix(unlist(lapply(glindx,unifqsum)),ncol=3,byrow=TRUE)
       for(k in 1:nxvar){xvars[[k]]=as.matrix(xvars[[k]][fs[,1],])}
       yvar=fs[,2];  fweights=fs[,3];   nunewr=length(yvar)
+      if(wtchk){weights=weights[fs[,1]]}
     } # end if(is.na(rparm[1]))
     
     ### get knot indices
@@ -195,7 +223,7 @@ makessp <-
                fweights=fweights,type=type,xdim=xdim,theknots=theknots,nknots=nknots,
                lambdas=lambdas,rks=rks[1:4],gcvopts=gcvopts,xorig=xorig,yorig=yorig,
                se.fit=se.fit,skip.iter=skip.iter,ysm=ysm,rparm=rparm,xrng=xrng,
-               flvls=flvls,tpsinfo=rks$tpsinfo,formula=formula,thetas=thetas)
+               flvls=flvls,tpsinfo=rks$tpsinfo,formula=formula,thetas=thetas,weights=weights)
     class(sspmk)<-"makessp"
     return(sspmk)
     
