@@ -1,16 +1,13 @@
 predict.ssa <-
-  function(object,newdata=NULL,se.fit=FALSE,
-           include=c(object$tnames),
-           effect=c("all","0","lin","non"),...) {
+  function(object,newdata=NULL,se.fit=FALSE,include=object$tnames,
+           effect=c("all","0","lin","non"),includeint=FALSE,...) {
     ###### Predicts for class "ssa" objects
     ###### Nathaniel E. Helwig (helwig@umn.edu)
-    ###### Last modified: August 26, 2014    
+    ###### Last modified: October 2, 2014
     
     ### check newdata
     effect=effect[1]
-    if(any(effect==c("all","0","lin","non"))==FALSE){
-      stop("Must set 'effect' to one of four specified options.")
-    }
+    if(any(effect==c("all","0","lin","non"))==FALSE){stop("Must set 'effect' to one of four specified options.")}
     if(effect=="0"){
       yhat=object$modelspec$coef[1]
       if(se.fit){
@@ -30,6 +27,7 @@ predict.ssa <-
       midx=match(newDnames,xnames)
       widx=which(is.na(midx))
       if(length(widx)>0){
+        if(length(widx)==length(newdata)){stop("Variable names in 'newdata' must match those of 'xvars' element of input 'object'.")}
         midx=midx[-widx]; newdata=newdata[-widx]; newDnames=newDnames[-widx]
         midx=match(newDnames,xnames)
       }
@@ -58,10 +56,11 @@ predict.ssa <-
     Etab[etidx,]=et[-1,];             Etab=rbind(0L,Etab)
     
     ### check for missing and transform
+    newdim=rep(NA,nxvar)
     for(k in 1:nxvar){
       if(sum(Etab[k+1L,])>0){
         if(any(is.na(newdata[[k]]))){
-          stop(paste("Missing data in 'newdata' for",xnames[k],"term in 'include' input."))
+          stop(paste("No data in 'newdata' for",xnames[k],"term in 'include' input."))
         }
         if(any(object$type[[k]]==c("cub","cub0","per","tps"))){
           newdata[[k]]=as.matrix(newdata[[k]]+0.0)
@@ -72,12 +71,10 @@ predict.ssa <-
         }
         if(any(object$type[[k]]==c("cub","cub0","per"))){
           newdata[[k]]=(newdata[[k]]-object$modelspec$xrng[[k]][1])/(object$modelspec$xrng[[k]][2]-object$modelspec$xrng[[k]][1])
-        } 
-      } else if(object$type[[k]]=="nom"){
-        fidx=match(newdata[[k]],object$modelspec$flvls[[k]])
-        if(any(is.na(fidx))){stop(paste("Inappropriate 'newdata' for",xnames[k],"(factor levels don't match)."))}
-        newdata[[k]]=as.matrix(fidx)
-      } # end if(sum(Etab[k+1L,])>0)
+        }
+        newdim[k]=nrow(newdata[[k]])
+        if(k>1L && newdim[k]!=max(newdim,na.rm=TRUE)){stop("Must have same number of observations for each covariate in newdata.")}
+      } else newdata[[k]]=NA # end if(sum(Etab[k+1L,])>0)
     } # end for(k in 1:nxvar)
     
     ### make marginal reproducing kernel matrices
@@ -85,7 +82,7 @@ predict.ssa <-
                 pred=TRUE,tpsinfo=object$modelspec$tpsinfo)
     
     ### make design and penalty matrices
-    if(lnt==length(oldnames) && effect=="all"){intid=TRUE} else {intid=FALSE}
+    if(lnt==length(oldnames) && effect=="all"){intid=TRUE} else {intid=includeint}
     dps=ssadpm(newdata,object$type,rks[1:3],object$modelspec$myknots,
                Etab,pred=TRUE,effect,intid)
     Knames=colnames(dps$Kmat)
@@ -103,8 +100,7 @@ predict.ssa <-
       if(is.null(dps$Jmats)){stop("No non/linear effect for terms in 'include' input.")}
       gamvec=NULL
       for(j in 1:Jlen){
-        xi=strsplit(Jnames[j],":")
-        xidx=match(xi[[1]],gnames)
+        xi=strsplit(Jnames[j],":"); xidx=match(xi[[1]],gnames)
         gamvec=c(gamvec,prod(object$modelspec$gammas[xidx]))
       }
       yhat=(dps$Jmats%*%kronecker(gamvec,diag(nknots)))%*%object$modelspec$coef[(nbf+1):(nbf+nknots)]
@@ -121,8 +117,7 @@ predict.ssa <-
       kidx=unique(kidx)
       gamvec=NULL
       for(j in 1:Jlen){
-        xi=strsplit(Jnames[j],":")
-        xidx=match(xi[[1]],gnames)
+        xi=strsplit(Jnames[j],":"); xidx=match(xi[[1]],gnames)
         gamvec=c(gamvec,prod(object$modelspec$gammas[xidx]))
       }
       yhat=cbind(dps$Kmat,dps$Jmats%*%kronecker(gamvec,diag(nknots)))%*%object$modelspec$coef[c(kidx,(nbf+1):(nbf+nknots))]
